@@ -13,20 +13,18 @@ class QQuickItemAutomator(pqaut.automator.qobject.QObjectAutomator):
         self._target = target
 
     def click(self):
-        pointf = self._target.mapToScene(QPointF(0.0, 0.0))
+        pointf = self.target.mapToScene(QPointF(0.0, 0.0))
         x = pointf.x()
         y = pointf.y()
         x += self.value_or_default("width", 0.0) / 2.0
         y += self.value_or_default("height", 0.0) / 2.0
         point = QPoint(x,y)
-        root_widget = pqaut.server.get_root_widget()
-        quick_widget = root_widget.target.childAt(point.x(), point.y())
-        pqaut.server.clicker.click_on(quick_widget, point)
+        pqaut.server.clicker.click_on(pqaut.server.get_root_widget().clickable_target(point), point)
 
     def is_offscreen(self):
-        root_widget = pqaut.server.get_root_widget()
-        root_width = root_widget.value_or_default('width', 0.0)
-        root_height = root_widget.value_or_default('height', 0.0)
+        first_child = pqaut.server.get_root_widget().get_children()[0]
+        root_width = first_child.value_or_default('width', 0.0)
+        root_height = first_child.value_or_default('height', 0.0)
         pointf = self._target.mapToScene(QPointF(0.0, 0.0))
         x = pointf.x()
         y = pointf.y()
@@ -38,8 +36,7 @@ class QQuickItemAutomator(pqaut.automator.qobject.QObjectAutomator):
         children = []
 
         try:
-            children = self.value_or_default('childItems', None)
-
+            children = self._target.childItems()
             if children is None:
                 children = self._target.findChildren(QObject)
         except Exception as e:
